# Description

Quick and easy way to secury import data from files in command line applications.

# Goals

* Easy and minimal to import
* Support multiple password backends (Plain text, lpass, vault...)
* Reusable
